Skip to content

Typography

The typography bundle provides classes for font families, font sizes, font weights, line heights, letter spacing, text alignment, and text transforms.

Import

js
import '@nikelaz/nadir/dist/nadir-typography.min.css';

Or as part of the full bundle:

js
import '@nikelaz/nadir/dist/nadir.min.css';

Font Family

These classes reference CSS custom properties. Set --nadir-ff-base and --nadir-ff-display in your own stylesheet to control which fonts are used.

ClassCSS Variable
.font-basevar(--nadir-ff-base)
.font-displayvar(--nadir-ff-display)

Font Size

ClassValue
.font-3xs0.1rem
.font-2xs0.25rem
.font-xs0.5rem
.font-sm0.75rem
.font-md1rem
.font-lg1.25rem
.font-xl1.5rem
.font-2xl1.75rem
.font-3xl2rem

Font Weight

Classfont-weight
.font-thin200
.font-light300
.font-regular400
.font-medium500
.font-semibold600
.font-bold700
.font-black900

Line Height

Classline-height
.leading-none1
.leading-tight1.25
.leading-snug1.375
.leading-normal1.5
.leading-relaxed1.625
.leading-loose2

Letter Spacing

Classletter-spacing
.tracking-tighter-0.05em
.tracking-tight-0.025em
.tracking-normal0em
.tracking-wide0.025em
.tracking-wider0.05em
.tracking-widest0.1em

Text Alignment

Classtext-align
.text-leftleft
.text-centercenter
.text-rightright
.text-justifyjustify
.text-startstart
.text-endend

Text Transform

Classtext-transform
.text-uppercaseuppercase
.text-lowercaselowercase
.text-capitalizecapitalize
.text-nonenone